@@ -18,7 +18,8 @@ from .schedd import get_best_schedd, get_schedd_ads, wait, remove_jobs
 from .preprocess import Preprocessor, preprocessing
 from .submit import SHFile, Submitter, CodeSubmitter
 from .cmssw import CMSSW
-from . import seutils
+from .cmssw_releases import get_arch
+import seutils
 
 if os.environ.get('HOSTNAME', '').endswith('fnal.gov'):
     # Fix to be able to import htcondor python bindings
@@ -30,6 +31,10 @@ if os.environ.get('HOSTNAME', '').endswith('fnal.gov'):
     schedd.GLOBAL_SCHEDDMAN_CLS = schedd.ScheddManagerFermiHTC
     DEFAULT_MGM = 'root://cmseos.fnal.gov'
 
+
+# ___________________________________________________
+# Short cuts
+
 def get_proc_id():
     if BATCHMODE:
         return int(os.environ['CONDOR_PROCESS_ID'])
@@ -37,17 +42,36 @@ def get_proc_id():
         logger.info('Local mode - return proc_id 0')
         return 0
 
-def get_preproc():
+CACHED_PREPROC = None
+
+def get_preproc(python_file=None):
     """
-    Determines the top level python file in the stack, and calls the preprocessor on that.
+    Returns and caches the preprocessing of a python file.
+    By default it picks the top level python file in the stack, and calls the preprocessor on that.
     """
-    import traceback
-    stack = traceback.extract_stack()
-    topfile = stack[0][0]
-    return preprocessing(topfile)
+    global CACHED_PREPROC
+    if CACHED_PREPROC: return CACHED_PREPROC
+    if not python_file:
+        import traceback
+        stack = traceback.extract_stack()
+        python_file = stack[0][0]
+    CACHED_PREPROC = preprocessing(python_file)
+    return CACHED_PREPROC
 
 def get_chunk():
     """Runs the preprocessor on the top level python file, and returns the chunk for the current proc_id"""
     chunks = get_preproc().chunks
     if not chunks: raise RuntimeError('No chunks determined in preprocessing')
     return chunks[get_proc_id()]
+
+def get_cluster_id():
+    if BATCHMODE:
+        return os.environ['CONDOR_CLUSTER_NUMBER']
+    else:
+        logger.info('Local mode - return cluster_id 1234')
+        return str(1234)
+
+def init_cmssw(tarball_key='cmssw_tarball', scram_arch=None):
+    cmssw_tarball = get_preproc().files[tarball_key]
+    cmssw = CMSSW.from_tarball(cmssw_tarball, scram_arch)
+    return cmssw
